/*  Note: You are free to use whatever license you want.
    Eventually you will be able to edit it within Glade. */

/*  xsteak
 *  Copyright (C) 1999 Razi Lotfi-Tabrizi (razi@cs.uni-frankfurt.de)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gtk/gtk.h>


void
on_window1_destroy                     (GtkObject       *object,
                                        gpointer         user_data);

void
on_buttonSearch_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_englishbutton2_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_or_checkbutton_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_and_checkbutton_toggled             (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_casesensitive_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_germanbutton1_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_buttonHelp_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_button2_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbutton3_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);
